@@ -22,6 +22,9 @@ getSample <- function(sampler, parametersOnly = T, coda = F, start = 1, end = NU
 
 # TODO: here we have to check many times if the object is a matrix to 
 # cover edge cases (single row/col). Maybe this should be restructured
+
+#' @rdname getSample
+#' @author Florian Hartig
 #' @export
 getSample.matrix <- function(sampler, parametersOnly = T, coda = F, start = 1, end = NULL, thin = "auto", numSamples = NULL, whichParameters = NULL, includesProbabilities = F, reportDiagnostics = F, ...){
   
@@ -31,7 +34,7 @@ getSample.matrix <- function(sampler, parametersOnly = T, coda = F, start = 1, e
     
     if(parametersOnly == T | includesProbabilities == F) {
       out = sampler[start:end,1:nPars] 
-      if(class(out) == "numeric") out = as.matrix(sampler) # case 1 parameter
+      if(class(out)[1] == "numeric") out = as.matrix(sampler) # case 1 parameter
     } else {
       out = out[start:end,]
       #if(!is.null(sampler$setup$names)) colnames(out) = c(sampler$setup$names, "Lposterior", "Llikelihood", "Lprior")
@@ -50,7 +53,6 @@ getSample.matrix <- function(sampler, parametersOnly = T, coda = F, start = 1, e
       out <- sampleEquallySpaced(out, numSamples)
     } else {
       sel = seq(1, nTotalSamples, by = thin)
-      
       out = out[sel,]
       if (!is.matrix(out)) out <- matrix(out, ncol = nPars)
     }
@@ -75,6 +77,7 @@ getSample.matrix <- function(sampler, parametersOnly = T, coda = F, start = 1, e
 }
 
 
+#' @rdname getSample
 #' @author Tankred Ott
 #' @export
 # TODO: This is right now only a helper function for getSample.mcmc. It is needed to return a vector istead of a matrix, if 
@@ -98,6 +101,7 @@ getSample.double <- function(sampler, parametersOnly = T, coda = F, start = 1, e
 }
 
 
+#' @rdname getSample
 #' @author Tankred Ott
 #' @export
 # TODO: This is right now only a helper function for getSample.mcmc. It is needed to return a vector instead of a matrix, if 
@@ -120,13 +124,14 @@ getSample.integer <- function(sampler, parametersOnly = T, coda = F, start = 1,
   return(out)
 }
 
+#' @rdname getSample
 #' @author Tankred Ott
 #' @export
 getSample.data.frame <- function(sampler, parametersOnly = T, coda = F, start = 1, end = NULL, thin = "auto", numSamples = NULL, whichParameters = NULL, includesProbabilities = F, reportDiagnostics = F, ...){
   getSample(as.matrix(sampler), parametersOnly = parametersOnly, coda = coda, start = start, end = end, thin = thin, whichParameters = whichParameters, includesProbabilities = includesProbabilities, reportDiagnostics = reportDiagnostics)
 }
 
-
+#' @rdname getSample
 #' @author Tankred Ott
 #' @export
 getSample.list <- function(sampler, parametersOnly = T, coda = F, start = 1, end = NULL, thin = "auto", numSamples = NULL, whichParameters = NULL, includesProbabilities = F, reportDiagnostics = F, ...){
@@ -162,6 +167,7 @@ getSample.list <- function(sampler, parametersOnly = T, coda = F, start = 1, end
 
 # The following two S3 implementations make getSample compatible with coda::mcmc and coda::mcmc.list
 
+#' @rdname getSample
 #' @author Tankred Ott
 #' @export
 getSample.mcmc <- function(sampler, parametersOnly = T, coda = F, start = 1, end = NULL, thin = "auto", numSamples = NULL, whichParameters = NULL, includesProbabilities = F, reportDiagnostics = F, ...){
@@ -196,6 +202,7 @@ getSample.mcmc <- function(sampler, parametersOnly = T, coda = F, start = 1, end
 
 
 #' @author Tankred Ott
+#' @rdname getSample
 #' @export
 getSample.mcmc.list <- function(sampler, parametersOnly = T, coda = F, start = 1, end = NULL, thin = "auto", numSamples = NULL, whichParameters = NULL, includesProbabilities = F, reportDiagnostics = F, ...){
   
@@ -228,14 +235,16 @@ getSample.mcmc.list <- function(sampler, parametersOnly = T, coda = F, start = 1
 }
 
 
-# getSample implementation for nimble objects
+# getSample implementation for nimble objects of class MCMC
 
+#' @rdname getSample
 #' @author Tankred Ott
 #' @export
 getSample.MCMC <- function(sampler, parametersOnly = T, coda = F, start = 1, end = NULL, thin = "auto", numSamples = NULL, whichParameters = NULL, includesProbabilities = F, reportDiagnostics = F, ...){
   return(getSample(as.matrix(sampler$mvSamples), parametersOnly = parametersOnly, coda = coda, start = start, end = end, thin = thin, numSamples = numSamples, whichParameters = whichParameters, includesProbabilities = includesProbabilities, reportDiagnostics = reportDiagnostics))
 }
 
+#' @rdname getSample
 #' @author Tankred Ott
 #' @export
 getSample.MCMC_refClass <- function(sampler, parametersOnly = T, coda = F, start = 1, end = NULL, thin = "auto", numSamples = NULL, whichParameters = NULL, includesProbabilities = F, reportDiagnostics = F, ...){
