@@ -4,13 +4,13 @@
 #' @export
 getSample.mcmcSampler <- function(sampler, parametersOnly = T, coda = F, start = 1, end = NULL, thin = 1, numSamples = NULL, whichParameters = NULL, includesProbabilities = F, reportDiagnostics= F, ...){
   
-  if (class(sampler$chain) == "matrix"){
+  if (class(sampler$chain)[1] == "matrix"){
     
     if(is.null(end)) end = nrow(sampler$chain)
     
     if(parametersOnly == T) {
       out = sampler$chain[start:end,1:sampler$setup$numPars] 
-      if(class(out) == "numeric") out = as.matrix(out) # case 1 parameter
+      if(class(out)[1] == "numeric") out = as.matrix(out) # case 1 parameter
       if(!is.null(sampler$setup$names)) colnames(out) = sampler$setup$names
     }
     else {
@@ -35,6 +35,8 @@ getSample.mcmcSampler <- function(sampler, parametersOnly = T, coda = F, start =
     if(thin == 1 && !is.null(numSamples)){
       out <- sampleEquallySpaced(out, numSamples)
     }
+
+    # TODO - see matrix, need to check if both thing and numSamples is set 
     
     #############
     
@@ -54,7 +56,7 @@ getSample.mcmcSampler <- function(sampler, parametersOnly = T, coda = F, start =
       
       if(parametersOnly == T) {
         temp = temp[,1:sampler$setup$numPars] 
-        if(class(temp) == "numeric") temp = as.matrix(temp) # case 1 parameter
+        if(class(temp)[1] == "numeric") temp = as.matrix(temp) # case 1 parameter
         if(!is.null(sampler$setup$names)) colnames(temp) = sampler$setup$names
       }
       else {
