@@ -16,11 +16,19 @@
 gelmanDiagnostics <- function(sampler, thin = "auto", plot = F, ...){
   sample = getSample(sampler, coda = T, ...)
   if(! ("mcmc.list" == class(sample))) stop("Trying to apply gelmanDiagnostics to an object that doesn't return an mcmc.list. Make sure you have a sampler that runs several chains, or an mcmcSamlerList")
-  diag = coda::gelman.diag(sample)
+  pars = ncol(sample[[1]])
+  diag = NULL
+  try({diag  = coda::gelman.diag(sample)}, silent = T)
+  if(is.null(diag)){
+    message("gelmanDiagnostics could not be calculated, possibly there is not enoug variance in your MCMC chains. Try running the sampler longer")
+    diag = list()
+    diag$psrf = matrix(nrow = pars, ncol = 2)
+    rownames(diag$psrf) = colnames(sample)
+    diag$mpsrf = NA  
+  } 
   # Wrapper around the gelman.plot to filter out getSample arguments from ...
   gP <- function(...,start, end, parametersOnly, coda, numSamples, whichParameters, includesProbabilities, reportDiagnostics, thin, plot, sampler) coda::gelman.plot(sample, ...)
-  if(plot == T) do.call(gP, as.list(match.call()))
+  if(plot == T & ! is.na(diag$mpsrf)) do.call(gP, as.list(match.call()))
   return(diag)
 }
 
-
