@@ -97,7 +97,7 @@ DEzs <- function(bayesianSetup,
     if(is.function(settings$startValue)){
       X = settings$startValue()
     }
-    if(class(settings$startValue) == "numeric"){
+    if(class(settings$startValue)[1] == "numeric"){
       X = bayesianSetup$prior$sampler(settings$startValue)
     }
     
@@ -111,7 +111,7 @@ DEzs <- function(bayesianSetup,
       Z = settings$Z()
     }
     
-    if(class(settings$Z) == "numeric"){
+    if(class(settings$Z)[1] == "numeric"){
       Z = bayesianSetup$prior$sampler(settings$Z)
     }
     if(is.matrix(settings$Z)) Z <- settings$Z
